@@ -1,11 +1,18 @@
 //  Boost config.hpp configuration test program file  -----------------------//
 
-//  (C) Copyright Boost.org 2000. Permission to copy, use, modify, sell and
-//  distribute this software is granted provided this copyright notice appears
-//  in all copies. This software is provided "as is" without express or implied
-//  warranty, and with no claim as to its suitability for any purpose.
+//  (C) Copyright John Maddock 2001 - 2003. 
+//  (C) Copyright Jens Maurer 2001. 
+//  (C) Copyright Peter Dimov 2001. 
+//  (C) Copyright Darin Adler 2001. 
+//  (C) Copyright Beman Dawes 2002. 
+//  Use, modification and distribution are subject to the 
+//  Boost Software License, Version 1.0. (See accompanying file 
+//  LICENSE_1_0.txt or copy at http://www.boost.org/LICENSE_1_0.txt)
 
-//  See http://www.boost.org for the most recent version.
+//  See http://www.boost.org/libs/config for most recent version.
+//
+//  Revision $Id$
+//
 
 #include <boost/config.hpp>
 #include <boost/version.hpp>
@@ -13,13 +20,19 @@
 #include <iomanip>
 #include <string.h>
 #include <limits.h>
+#include <stdlib.h>
+#include <stddef.h>
 
 #ifdef BOOST_HAS_UNISTD_H
 #include <unistd.h>
 #endif
 
-unsigned int indent = 4;
-unsigned int width = 40;
+#if defined(__MINGW32__)
+#  include <_mingw.h>
+#endif
+
+static unsigned int indent = 4;
+static unsigned int width = 40;
 
 using std::cout;
 using std::istream;
@@ -67,7 +80,7 @@ void print_byte_order(const char* what, T /* t */ )
    unsigned i;
    for(i = 1; i < sizeof(T); ++i)
    {
-      val |= (CHAR_BIT * i) << (CHAR_BIT * i);
+      val |= (CHAR_BIT * static_cast<T>(i)) << (CHAR_BIT * static_cast<T>(i));
    }
    const char* p = reinterpret_cast<const char*>(&val);
 
@@ -118,6 +131,8 @@ void print_compiler_macros()
   PRINT_MACRO(_Windows);
   PRINT_MACRO(__WIN32__);
   PRINT_MACRO(_WIN32);
+  PRINT_MACRO(_WIN64);
+  PRINT_MACRO(_WIN32_WCE);
   PRINT_MACRO(WIN32);
   PRINT_MACRO(_RTLDLL);
   PRINT_MACRO(__DEBUG);
@@ -128,29 +143,66 @@ void print_compiler_macros()
   PRINT_MACRO(_WCHAR_T_DEFINED);
 #endif
   // MSVC macros:
+  PRINT_MACRO(_ALIGNED_NEW_SUPPORTED);
+  PRINT_MACRO(__ATOM__);
+  PRINT_MACRO(__AVX__);
+  PRINT_MACRO(__AVX2__);
+  PRINT_MACRO(_CHAR_UNSIGNED);
+  PRINT_MACRO(_CLR_VER);
+  PRINT_MACRO(_CONTROL_FLOW_GUARD);
+  PRINT_MACRO(__cplusplus_cli);
+  PRINT_MACRO(__cplusplus_winrt);
   PRINT_MACRO(_CPPRTTI);
+  PRINT_MACRO(_CPPUNWIND);
   PRINT_MACRO(_DLL);
+  PRINT_MACRO(_INLINE_VARIABLES_SUPPORTED);
+  PRINT_MACRO(_ISO_VOLATILE);
+  PRINT_MACRO(_M_AMD64);
+  PRINT_MACRO(_M_ARM);
+  PRINT_MACRO(_M_ARM_ARMV7VE);
+  PRINT_MACRO(_M_ARM_FP);
+  PRINT_MACRO(_M_ARM64);
+  PRINT_MACRO(_M_CEE);
+  PRINT_MACRO(_M_CEE_PURE);
+  PRINT_MACRO(_M_CEE_SAFE);
+  PRINT_MACRO(_M_FP_EXCEPT);
+  PRINT_MACRO(_M_FP_FAST);
+  PRINT_MACRO(_M_FP_PRECISE);
+  PRINT_MACRO(_M_FP_STRICT);
+  PRINT_MACRO(_M_IX86);
+  PRINT_MACRO(_M_IX86_FP);
+  PRINT_MACRO(_M_X64);
   PRINT_MACRO(_M_ALPHA);
   PRINT_MACRO(_M_MPPC);
   PRINT_MACRO(_M_MRX000);
   PRINT_MACRO(_M_PPC);
+  PRINT_MACRO(_MANAGED);
+  PRINT_MACRO(_MSC_BUILD);
   PRINT_MACRO(_MFC_VER);
   PRINT_MACRO(_MSC_EXTENSIONS);
   PRINT_MACRO(_MSC_VER);
+  PRINT_MACRO(_MSC_FULL_VER);
+  PRINT_MACRO(_MSVC_LANG);
+  PRINT_MACRO(_MSVC_WARNING_LEVEL);
+  PRINT_MACRO(__MSVC_RUNTIME_CHECKS);
   PRINT_MACRO(_MT);
   PRINT_MACRO(_NATIVE_WCHAR_T_DEFINED);
+  PRINT_MACRO(_NOEXCEPT_TYPES_SUPPORTED);
+  PRINT_MACRO(_OPENMP);
+  PRINT_MACRO(_PREFAST_);
   // GNUC options:
   PRINT_MACRO(__GNUC__);
   PRINT_MACRO(__GNUC_MINOR__);
+  PRINT_MACRO(__GNUC_PATCHLEVEL__);
   PRINT_MACRO(__STDC_VERSION__);
   PRINT_MACRO(__GNUG__);
   PRINT_MACRO(__STRICT_ANSI__);
+  PRINT_MACRO(__GXX_EXPERIMENTAL_CXX0X__);
   PRINT_MACRO(__VERSION__);
   PRINT_MACRO(__OPTIMIZE__);
   PRINT_MACRO(__CHAR_UNSIGNED__);
   PRINT_MACRO(__REGISTER_PREFIX__);
   PRINT_MACRO(__USER_LABEL_PREFIX__);
-  PRINT_MACRO(__INTEL__);
   PRINT_MACRO(__GNUPRO__);
   PRINT_MACRO(__EXCEPTIONS);
   PRINT_MACRO(__FreeBSD__);
@@ -173,6 +225,35 @@ void print_compiler_macros()
   PRINT_MACRO(__sparc__);
   PRINT_MACRO(__powerpc__);
   PRINT_MACRO(__hppa);
+  PRINT_MACRO(__CYGWIN__);
+  PRINT_MACRO(__MINGW32__);
+  PRINT_MACRO(__GXX_RTTI);
+  PRINT_MACRO(__alpha__);
+  PRINT_MACRO(__amd64__);
+  PRINT_MACRO(__arm__);
+  PRINT_MACRO(__aarch64__);
+  PRINT_MACRO(__bfin);
+  PRINT_MACRO(__convex__);
+  PRINT_MACRO(__epiphany__);
+  PRINT_MACRO(__hppa__);
+  PRINT_MACRO(__ia64__);
+  PRINT_MACRO(__IA64);
+  PRINT_MACRO(__IA64__);
+  PRINT_MACRO(__m68k__);
+  PRINT_MACRO(__mips__);
+  PRINT_MACRO(__powerpc);
+  PRINT_MACRO(__powerpc__);
+  PRINT_MACRO(__powerpc64__);
+  PRINT_MACRO(__POWERPC__);
+  PRINT_MACRO(__ppc__);
+  PRINT_MACRO(__ppc64__);
+  PRINT_MACRO(__PPC__);
+  PRINT_MACRO(__PPC64__);
+  PRINT_MACRO(_ARCH_PPC);
+  PRINT_MACRO(_ARCH_PPC64);
+  PRINT_MACRO(__sh__);
+  PRINT_MACRO(__370__);
+  PRINT_MACRO(__THW_370__);
   // HP aCC:
   PRINT_MACRO(__HP_aCC);
   PRINT_MACRO(_HPACC_);
@@ -185,6 +266,7 @@ void print_compiler_macros()
   PRINT_MACRO(__hp9000s700);
   PRINT_MACRO(_PA_RISC1_1);
   PRINT_MACRO(__HPUX_SOURCE);
+  PRINT_MACRO(_INCLUDE__STDC_A1_SOURCE);
   // SGI IRIX:
   PRINT_MACRO(__sgi);
   PRINT_MACRO(_COMPILER_VERSION);
@@ -256,11 +338,50 @@ void print_compiler_macros()
   PRINT_MACRO(__RTTI);
   PRINT_MACRO(__PLACEMENT_DELETE);
   PRINT_MACRO(__NO_LONG_LONG);
-  
-  // misc compilers not covered so far:
+
+  // Intel options:
+  PRINT_MACRO(__INTEL__);
   PRINT_MACRO(__ICC);
   PRINT_MACRO(__ICL);
+  PRINT_MACRO(__ECC);
   PRINT_MACRO(__INTEL_COMPILER);
+  PRINT_MACRO(__INITIAL_POINTER_SIZE);
+  PRINT_MACRO(_INTEGRAL_MAX_BITS);
+  PRINT_MACRO(__INTEL_COMPILER_BUILD_DATE);
+  PRINT_MACRO(__INTEL_MS_COMPAT_LEVEL);
+  PRINT_MACRO(__LONG_DOUBLE_SIZE__);
+  PRINT_MACRO(_M_X64);
+  PRINT_MACRO(_OPENMP);
+  PRINT_MACRO(_OPENMPT);
+  PRINT_MACRO(_PGO_INSTRUMENT);
+  PRINT_MACRO(__QMSPP_); 
+  PRINT_MACRO(__INTEL_RTTI__);
+  PRINT_MACRO(__INTEL_CXX11_MODE__);
+
+  // Cray options:
+  PRINT_MACRO(_CRAYC); 
+  PRINT_MACRO(_RELEASE); 
+  PRINT_MACRO(cray); 
+  PRINT_MACRO(CRAY); 
+  PRINT_MACRO(CRAY1); 
+  PRINT_MACRO(_CRAY1); 
+  PRINT_MACRO(_CRAYMPP); 
+  PRINT_MACRO(_CRAYT3E); 
+  PRINT_MACRO(_CRAYIEEE); 
+  PRINT_MACRO(_ADDR32); 
+  PRINT_MACRO(_ADDR64); 
+  PRINT_MACRO(_LD64); 
+  PRINT_MACRO(_FASTMD); 
+  PRINT_MACRO(_MAXVL); 
+
+  // clang options:
+  PRINT_MACRO(__clang__); 
+  PRINT_MACRO(__clang_major__);
+  PRINT_MACRO(__clang_minor__);
+  PRINT_MACRO(__clang_version__);
+  PRINT_MACRO(__clang_patchlevel__);
+
+  // misc compilers not covered so far:
   PRINT_MACRO(__USLC__);
   PRINT_MACRO(__DECCXX);
   PRINT_MACRO(__IBMCPP__);
@@ -269,6 +390,25 @@ void print_compiler_macros()
   PRINT_MACRO(__STDC_HOSTED__);
   PRINT_MACRO(__COMO__);
   PRINT_MACRO(__COMO_VERSION__);
+  PRINT_MACRO(__DM__);
+  PRINT_MACRO(__osf__);
+  PRINT_MACRO(__OSF__);
+  PRINT_MACRO(__QNXNTO__);
+  PRINT_MACRO(__QNX__);
+  PRINT_MACRO(_NTO_VERSION);
+  PRINT_MACRO(__OPEN64__);
+  PRINT_MACRO(__open64);
+  PRINT_MACRO(__NVCC__);
+  PRINT_MACRO(__CUDACC__);
+  PRINT_MACRO(__CUDACC_RDC__);
+  PRINT_MACRO(__CUDACC_VER_MAJOR__);
+  PRINT_MACRO(__CUDACC_VER_MINOR__);
+  PRINT_MACRO(__CUDACC_VER_BUILD__);
+  PRINT_MACRO(__CUDACC_VER__);
+
+  // Android:
+  PRINT_MACRO(ANDROID);
+  PRINT_MACRO(__ANDROID__);
 }
 
 void print_stdlib_macros()
@@ -501,10 +641,35 @@ void print_stdlib_macros()
    #endif
    // Dinkumware options:
    PRINT_MACRO(_CPPLIB_VER);
+   PRINT_MACRO(_MSVC_STL_VERSION); // VS2017 15.5+
+   PRINT_MACRO(_MSVC_STL_UPDATE);  // VS2017 15.5+
    PRINT_MACRO(_GLOBAL_USING);
    PRINT_MACRO(_HAS_EXCEPTIONS);
    PRINT_MACRO(_HAS_MEMBER_TEMPLATES_REBIND);
    PRINT_MACRO(_HAS_TEMPLATE_PARTIAL_ORDERING);
+   // https://blogs.msdn.microsoft.com/vcblog/2016/08/12/stl-fixes-in-vs-2015-update-3/
+   PRINT_MACRO(_HAS_CXX17);
+   PRINT_MACRO(_HAS_AUTO_PTR_ETC);
+   PRINT_MACRO(_HAS_OLD_IOSTREAMS_MEMBERS);
+   PRINT_MACRO(_HAS_FUNCTION_ASSIGN);
+   PRINT_MACRO(_HAS_TR1_NAMESPACE);
+   PRINT_MACRO(_HAS_IDENTITY_STRUCT);
+   // VS2017 15.5+
+   PRINT_MACRO(_HAS_STATIC_RTTI);
+   PRINT_MACRO(_HAS_UNEXPECTED);
+   PRINT_MACRO(_HAS_STD_BYTE);
+   PRINT_MACRO(_HAS_FUNCTION_ALLOCATOR_SUPPORT);
+   PRINT_MACRO(_HAS_TR2_SYS_NAMESPACE);
+   PRINT_MACRO(_ENFORCE_MATCHING_ALLOCATORS);
+   PRINT_MACRO(_HAS_HAS_UNIQUE_OBJECT_REPRESENTATIONS);
+   PRINT_MACRO(_HAS_INLINE_VARIABLES);
+   PRINT_MACRO(_HAS_ALIGNED_NEW);
+   PRINT_MACRO(_HAS_NOEXCEPT_FUNCTION_TYPES);
+   PRINT_MACRO(_ITERATOR_DEBUG_LEVEL);
+   PRINT_MACRO(_HAS_ITERATOR_DEBUGGING);
+   PRINT_MACRO(_ITERATOR_DEBUG_ARRAY_OVERLOADS);
+   // Libc++:
+   PRINT_MACRO(_LIBCPP_VERSION);
    // STLPort and generic SGI STL options:
    PRINT_MACRO(__SGI_STL_NO_ARROW_OPERATOR);
    PRINT_MACRO(__SGI_STL_OWN_IOSTREAMS);
@@ -669,6 +834,21 @@ void print_stdlib_macros()
    PRINT_MACRO(__GLIBCPP__);
    PRINT_MACRO(_GLIBCPP_USE_WCHAR_T);
    PRINT_MACRO(_GLIBCPP_VERSION);
+   PRINT_MACRO(__GLIBCXX__);
+   PRINT_MACRO(_GLIBCXX_USE_WCHAR_T);
+   PRINT_MACRO(_GLIBCXX_VERSION);
+   PRINT_MACRO(_GLIBCXX_USE_LONG_LONG);
+   PRINT_MACRO(_GLIBCXX_USE_NLS);
+   PRINT_MACRO(_GLIBCXX_USE_C99_MATH);
+   PRINT_MACRO(_GLIBCXX_USE_C99);
+   PRINT_MACRO(_GLIBCXX_CONCEPT_CHECKS);
+   PRINT_MACRO(_GLIBCXX_USE_LFS);
+   PRINT_MACRO(_GLIBCXX_SYMVER);
+   PRINT_MACRO(_GLIBCXX_MEM_LIMITS);
+   PRINT_MACRO(_GLIBCXX_HOSTED);
+   PRINT_MACRO(_GLIBCXX_SJLJ_EXCEPTIONS);
+   PRINT_MACRO(_GLIBCXX_RELEASE);
+
    // Modena C++ standard library
    PRINT_MACRO(MSIPL_ANSI_HEADER);
    PRINT_MACRO(MSIPL_BOOL_BUILTIN);
@@ -704,6 +884,10 @@ void print_platform_macros()
    PRINT_EXPRESSION(sizeof(short));
    PRINT_EXPRESSION(sizeof(int));
    PRINT_EXPRESSION(sizeof(long));
+   PRINT_EXPRESSION(sizeof(size_t));
+   PRINT_EXPRESSION(sizeof(ptrdiff_t));
+   PRINT_EXPRESSION(sizeof(void*));
+   PRINT_EXPRESSION(sizeof(void(*)(void)));
    PRINT_EXPRESSION(sizeof(float));
    PRINT_EXPRESSION(sizeof(double));
    PRINT_EXPRESSION(sizeof(long double));
@@ -717,6 +901,9 @@ void print_platform_macros()
    PRINT_MACRO(LLONG_MAX);
    PRINT_MACRO(LONG_LONG_MAX);
    PRINT_MACRO(LONGLONG_MAX);
+   PRINT_MACRO(ULLONG_MAX); // <boost/cstdint.hpp> uses these, so we need to know them
+   PRINT_MACRO(ULONG_LONG_MAX);
+   PRINT_MACRO(ULONGLONG_MAX);
    // general C99:
    PRINT_MACRO(__STDC_IEC_559__);
    PRINT_MACRO(__STDC_IEC_559_COMPLEX__);
@@ -726,7 +913,6 @@ void print_platform_macros()
    PRINT_MACRO(__GLIBC_MINOR__);
    PRINT_MACRO(__GNU_LIBRARY__);
    PRINT_MACRO(_BSD_SOURCE);
-   PRINT_MACRO(_FILE_OFFSET_BITS);
    PRINT_MACRO(_GNU_SOURCE);
    PRINT_MACRO(_ISOC99_SOURCE);
    PRINT_MACRO(_ISOC9X_SOURCE);
@@ -736,6 +922,8 @@ void print_platform_macros()
    PRINT_MACRO(_THREAD_SAFE);
    PRINT_MACRO(_XOPEN_SOURCE_EXTENDED);
    PRINT_MACRO(XPG);
+   PRINT_MACRO(__MINGW32_MAJOR_VERSION);
+   PRINT_MACRO(__MINGW32_MINOR_VERSION);
    // POSIX:
    PRINT_MACRO(_POSIX_ADVISORY_INFO);
    PRINT_MACRO(_POSIX_ASYNCHRONOUS_IO);
@@ -820,72 +1008,198 @@ void print_platform_macros()
    PRINT_MACRO(_XOPEN_STREAMS);
    PRINT_MACRO(_XOPEN_UNIX);
    PRINT_MACRO(_XOPEN_VERSION);
+   // Misc:
+   PRINT_MACRO(__USE_BSD);
+   PRINT_MACRO(_FILE_OFFSET_BITS);
 }
 
 void print_boost_macros()
 {
    std::cout << "Boost version " << BOOST_STRINGIZE(BOOST_VERSION) << std::endl;
-   PRINT_MACRO(BOOST_BCB_PARTIAL_SPECIALIZATION_BUG);
-   PRINT_MACRO(BOOST_DECL);
+   // config setup macros first:
+   PRINT_MACRO(BOOST_USER_CONFIG);
+   PRINT_MACRO(BOOST_COMPILER_CONFIG);
+   PRINT_MACRO(BOOST_STDLIB_CONFIG);
+   PRINT_MACRO(BOOST_PLATFORM_CONFIG);
+   PRINT_MACRO(BOOST_NO_CONFIG);
+   PRINT_MACRO(BOOST_NO_USER_CONFIG);
+   PRINT_MACRO(BOOST_NO_COMPILER_CONFIG);
+   PRINT_MACRO(BOOST_NO_STDLIB_CONFIG);
+   PRINT_MACRO(BOOST_NO_PLATFORM_CONFIG);
+   // then defect and feature macros:
    PRINT_MACRO(BOOST_DISABLE_THREADS);
    PRINT_MACRO(BOOST_DISABLE_WIN32);
+   PRINT_MACRO(BOOST_HAS_THREADS);
+   PRINT_MACRO(BOOST_WINDOWS);
+
+   // BEGIN GENERATED BLOCK DO NOT EDIT THIS!!!!!!
+   PRINT_MACRO(BOOST_BCB_PARTIAL_SPECIALIZATION_BUG);
+   PRINT_MACRO(BOOST_DEDUCED_TYPENAME);
+   PRINT_MACRO(BOOST_FUNCTION_SCOPE_USING_DECLARATION_BREAKS_ADL);
    PRINT_MACRO(BOOST_HAS_BETHREADS);
    PRINT_MACRO(BOOST_HAS_CLOCK_GETTIME);
    PRINT_MACRO(BOOST_HAS_DIRENT_H);
+   PRINT_MACRO(BOOST_HAS_EXPM1);
+   PRINT_MACRO(BOOST_HAS_FLOAT128);
    PRINT_MACRO(BOOST_HAS_FTIME);
+   PRINT_MACRO(BOOST_HAS_GETSYSTEMTIMEASFILETIME);
    PRINT_MACRO(BOOST_HAS_GETTIMEOFDAY);
    PRINT_MACRO(BOOST_HAS_HASH);
+   PRINT_MACRO(BOOST_HAS_INT128);
+   PRINT_MACRO(BOOST_HAS_LOG1P);
    PRINT_MACRO(BOOST_HAS_LONG_LONG);
    PRINT_MACRO(BOOST_HAS_MACRO_USE_FACET);
    PRINT_MACRO(BOOST_HAS_MS_INT64);
    PRINT_MACRO(BOOST_HAS_NANOSLEEP);
    PRINT_MACRO(BOOST_HAS_NL_TYPES_H);
+   PRINT_MACRO(BOOST_HAS_NRVO);
+   PRINT_MACRO(BOOST_HAS_PARTIAL_STD_ALLOCATOR);
+   PRINT_MACRO(BOOST_HAS_PTHREADS);
    PRINT_MACRO(BOOST_HAS_PTHREAD_DELAY_NP);
    PRINT_MACRO(BOOST_HAS_PTHREAD_MUTEXATTR_SETTYPE);
    PRINT_MACRO(BOOST_HAS_PTHREAD_YIELD);
-   PRINT_MACRO(BOOST_HAS_PTHREADS);
+   PRINT_MACRO(BOOST_HAS_RVALUE_REFS);
    PRINT_MACRO(BOOST_HAS_SCHED_YIELD);
    PRINT_MACRO(BOOST_HAS_SGI_TYPE_TRAITS);
-   PRINT_MACRO(BOOST_HAS_STDINT_H);
+   PRINT_MACRO(BOOST_HAS_SIGACTION);
    PRINT_MACRO(BOOST_HAS_SLIST);
+   PRINT_MACRO(BOOST_HAS_STATIC_ASSERT);
+   PRINT_MACRO(BOOST_HAS_STDINT_H);
    PRINT_MACRO(BOOST_HAS_STLP_USE_FACET);
-   PRINT_MACRO(BOOST_HAS_THREADS);
    PRINT_MACRO(BOOST_HAS_TWO_ARG_USE_FACET);
    PRINT_MACRO(BOOST_HAS_UNISTD_H);
+   PRINT_MACRO(BOOST_HAS_VARIADIC_TMPL);
    PRINT_MACRO(BOOST_HAS_WINTHREADS);
-   PRINT_MACRO(BOOST_MSVC);
-   PRINT_MACRO(BOOST_MSVC_STD_ITERATOR);
    PRINT_MACRO(BOOST_MSVC6_MEMBER_TEMPLATES);
-   PRINT_MACRO(BOOST_NESTED_TEMPLATE);
+   PRINT_MACRO(BOOST_MSVC_STD_ITERATOR);
+   PRINT_MACRO(BOOST_NO_ADL_BARRIER);
    PRINT_MACRO(BOOST_NO_ARGUMENT_DEPENDENT_LOOKUP);
+   PRINT_MACRO(BOOST_NO_ARRAY_TYPE_SPECIALIZATIONS);
    PRINT_MACRO(BOOST_NO_AUTO_PTR);
+   PRINT_MACRO(BOOST_NO_COMPLETE_VALUE_INITIALIZATION);
    PRINT_MACRO(BOOST_NO_CTYPE_FUNCTIONS);
    PRINT_MACRO(BOOST_NO_CV_SPECIALIZATIONS);
    PRINT_MACRO(BOOST_NO_CV_VOID_SPECIALIZATIONS);
    PRINT_MACRO(BOOST_NO_CWCHAR);
    PRINT_MACRO(BOOST_NO_CWCTYPE);
+   PRINT_MACRO(BOOST_NO_CXX11_ADDRESSOF);
+   PRINT_MACRO(BOOST_NO_CXX11_ALIGNAS);
+   PRINT_MACRO(BOOST_NO_CXX11_ALLOCATOR);
+   PRINT_MACRO(BOOST_NO_CXX11_ATOMIC_SMART_PTR);
+   PRINT_MACRO(BOOST_NO_CXX11_AUTO_DECLARATIONS);
+   PRINT_MACRO(BOOST_NO_CXX11_AUTO_MULTIDECLARATIONS);
+   PRINT_MACRO(BOOST_NO_CXX11_CHAR16_T);
+   PRINT_MACRO(BOOST_NO_CXX11_CHAR32_T);
+   PRINT_MACRO(BOOST_NO_CXX11_CONSTEXPR);
+   PRINT_MACRO(BOOST_NO_CXX11_DECLTYPE);
+   PRINT_MACRO(BOOST_NO_CXX11_DECLTYPE_N3276);
+   PRINT_MACRO(BOOST_NO_CXX11_DEFAULTED_FUNCTIONS);
+   PRINT_MACRO(BOOST_NO_CXX11_DEFAULTED_MOVES);
+   PRINT_MACRO(BOOST_NO_CXX11_DELETED_FUNCTIONS);
+   PRINT_MACRO(BOOST_NO_CXX11_EXPLICIT_CONVERSION_OPERATORS);
+   PRINT_MACRO(BOOST_NO_CXX11_EXTERN_TEMPLATE);
+   PRINT_MACRO(BOOST_NO_CXX11_FINAL);
+   PRINT_MACRO(BOOST_NO_CXX11_FIXED_LENGTH_VARIADIC_TEMPLATE_EXPANSION_PACKS);
+   PRINT_MACRO(BOOST_NO_CXX11_FUNCTION_TEMPLATE_DEFAULT_ARGS);
+   PRINT_MACRO(BOOST_NO_CXX11_HDR_ARRAY);
+   PRINT_MACRO(BOOST_NO_CXX11_HDR_ATOMIC);
+   PRINT_MACRO(BOOST_NO_CXX11_HDR_CHRONO);
+   PRINT_MACRO(BOOST_NO_CXX11_HDR_CODECVT);
+   PRINT_MACRO(BOOST_NO_CXX11_HDR_CONDITION_VARIABLE);
+   PRINT_MACRO(BOOST_NO_CXX11_HDR_FORWARD_LIST);
+   PRINT_MACRO(BOOST_NO_CXX11_HDR_FUNCTIONAL);
+   PRINT_MACRO(BOOST_NO_CXX11_HDR_FUTURE);
+   PRINT_MACRO(BOOST_NO_CXX11_HDR_INITIALIZER_LIST);
+   PRINT_MACRO(BOOST_NO_CXX11_HDR_MUTEX);
+   PRINT_MACRO(BOOST_NO_CXX11_HDR_RANDOM);
+   PRINT_MACRO(BOOST_NO_CXX11_HDR_RATIO);
+   PRINT_MACRO(BOOST_NO_CXX11_HDR_REGEX);
+   PRINT_MACRO(BOOST_NO_CXX11_HDR_SYSTEM_ERROR);
+   PRINT_MACRO(BOOST_NO_CXX11_HDR_THREAD);
+   PRINT_MACRO(BOOST_NO_CXX11_HDR_TUPLE);
+   PRINT_MACRO(BOOST_NO_CXX11_HDR_TYPEINDEX);
+   PRINT_MACRO(BOOST_NO_CXX11_HDR_TYPE_TRAITS);
+   PRINT_MACRO(BOOST_NO_CXX11_HDR_UNORDERED_MAP);
+   PRINT_MACRO(BOOST_NO_CXX11_HDR_UNORDERED_SET);
+   PRINT_MACRO(BOOST_NO_CXX11_INLINE_NAMESPACES);
+   PRINT_MACRO(BOOST_NO_CXX11_LAMBDAS);
+   PRINT_MACRO(BOOST_NO_CXX11_LOCAL_CLASS_TEMPLATE_PARAMETERS);
+   PRINT_MACRO(BOOST_NO_CXX11_NOEXCEPT);
+   PRINT_MACRO(BOOST_NO_CXX11_NON_PUBLIC_DEFAULTED_FUNCTIONS);
+   PRINT_MACRO(BOOST_NO_CXX11_NULLPTR);
+   PRINT_MACRO(BOOST_NO_CXX11_NUMERIC_LIMITS);
+   PRINT_MACRO(BOOST_NO_CXX11_POINTER_TRAITS);
+   PRINT_MACRO(BOOST_NO_CXX11_RANGE_BASED_FOR);
+   PRINT_MACRO(BOOST_NO_CXX11_RAW_LITERALS);
+   PRINT_MACRO(BOOST_NO_CXX11_REF_QUALIFIERS);
+   PRINT_MACRO(BOOST_NO_CXX11_RVALUE_REFERENCES);
+   PRINT_MACRO(BOOST_NO_CXX11_SCOPED_ENUMS);
+   PRINT_MACRO(BOOST_NO_CXX11_SFINAE_EXPR);
+   PRINT_MACRO(BOOST_NO_CXX11_SMART_PTR);
+   PRINT_MACRO(BOOST_NO_CXX11_STATIC_ASSERT);
+   PRINT_MACRO(BOOST_NO_CXX11_STD_ALIGN);
+   PRINT_MACRO(BOOST_NO_CXX11_TEMPLATE_ALIASES);
+   PRINT_MACRO(BOOST_NO_CXX11_THREAD_LOCAL);
+   PRINT_MACRO(BOOST_NO_CXX11_TRAILING_RESULT_TYPES);
+   PRINT_MACRO(BOOST_NO_CXX11_UNICODE_LITERALS);
+   PRINT_MACRO(BOOST_NO_CXX11_UNIFIED_INITIALIZATION_SYNTAX);
+   PRINT_MACRO(BOOST_NO_CXX11_USER_DEFINED_LITERALS);
+   PRINT_MACRO(BOOST_NO_CXX11_VARIADIC_MACROS);
+   PRINT_MACRO(BOOST_NO_CXX11_VARIADIC_TEMPLATES);
+   PRINT_MACRO(BOOST_NO_CXX14_AGGREGATE_NSDMI);
+   PRINT_MACRO(BOOST_NO_CXX14_BINARY_LITERALS);
+   PRINT_MACRO(BOOST_NO_CXX14_CONSTEXPR);
+   PRINT_MACRO(BOOST_NO_CXX14_DECLTYPE_AUTO);
+   PRINT_MACRO(BOOST_NO_CXX14_DIGIT_SEPARATORS);
+   PRINT_MACRO(BOOST_NO_CXX14_GENERIC_LAMBDAS);
+   PRINT_MACRO(BOOST_NO_CXX14_HDR_SHARED_MUTEX);
+   PRINT_MACRO(BOOST_NO_CXX14_INITIALIZED_LAMBDA_CAPTURES);
+   PRINT_MACRO(BOOST_NO_CXX14_RETURN_TYPE_DEDUCTION);
+   PRINT_MACRO(BOOST_NO_CXX14_STD_EXCHANGE);
+   PRINT_MACRO(BOOST_NO_CXX14_VARIABLE_TEMPLATES);
+   PRINT_MACRO(BOOST_NO_CXX17_FOLD_EXPRESSIONS);
+   PRINT_MACRO(BOOST_NO_CXX17_INLINE_VARIABLES);
+   PRINT_MACRO(BOOST_NO_CXX17_ITERATOR_TRAITS);
+   PRINT_MACRO(BOOST_NO_CXX17_STD_APPLY);
+   PRINT_MACRO(BOOST_NO_CXX17_STD_INVOKE);
+   PRINT_MACRO(BOOST_NO_CXX17_STRUCTURED_BINDINGS);
+   PRINT_MACRO(BOOST_NO_CXX98_BINDERS);
+   PRINT_MACRO(BOOST_NO_CXX98_FUNCTION_BASE);
+   PRINT_MACRO(BOOST_NO_CXX98_RANDOM_SHUFFLE);
    PRINT_MACRO(BOOST_NO_DEPENDENT_NESTED_DERIVATIONS);
    PRINT_MACRO(BOOST_NO_DEPENDENT_TYPES_IN_TEMPLATE_VALUE_PARAMETERS);
    PRINT_MACRO(BOOST_NO_EXCEPTIONS);
+   PRINT_MACRO(BOOST_NO_EXCEPTION_STD_NAMESPACE);
    PRINT_MACRO(BOOST_NO_EXPLICIT_FUNCTION_TEMPLATE_ARGUMENTS);
+   PRINT_MACRO(BOOST_NO_FENV_H);
    PRINT_MACRO(BOOST_NO_FUNCTION_TEMPLATE_ORDERING);
-   PRINT_MACRO(BOOST_NO_HASH);
+   PRINT_MACRO(BOOST_NO_FUNCTION_TYPE_SPECIALIZATIONS);
    PRINT_MACRO(BOOST_NO_INCLASS_MEMBER_INITIALIZATION);
-   PRINT_MACRO(BOOST_NO_INT64_T);
    PRINT_MACRO(BOOST_NO_INTEGRAL_INT64_T);
    PRINT_MACRO(BOOST_NO_INTRINSIC_WCHAR_T);
+   PRINT_MACRO(BOOST_NO_IOSFWD);
+   PRINT_MACRO(BOOST_NO_IOSTREAM);
+   PRINT_MACRO(BOOST_NO_IS_ABSTRACT);
    PRINT_MACRO(BOOST_NO_LIMITS);
    PRINT_MACRO(BOOST_NO_LIMITS_COMPILE_TIME_CONSTANTS);
+   PRINT_MACRO(BOOST_NO_LONG_LONG);
    PRINT_MACRO(BOOST_NO_LONG_LONG_NUMERIC_LIMITS);
    PRINT_MACRO(BOOST_NO_MEMBER_FUNCTION_SPECIALIZATIONS);
-   PRINT_MACRO(BOOST_NO_MEMBER_TEMPLATE_KEYWORD);
-   PRINT_MACRO(BOOST_NO_MEMBER_TEMPLATE_FRIENDS);
    PRINT_MACRO(BOOST_NO_MEMBER_TEMPLATES);
+   PRINT_MACRO(BOOST_NO_MEMBER_TEMPLATE_FRIENDS);
+   PRINT_MACRO(BOOST_NO_MEMBER_TEMPLATE_KEYWORD);
    PRINT_MACRO(BOOST_NO_MS_INT64_NUMERIC_LIMITS);
+   PRINT_MACRO(BOOST_NO_NESTED_FRIENDSHIP);
    PRINT_MACRO(BOOST_NO_OPERATORS_IN_NAMESPACE);
+   PRINT_MACRO(BOOST_NO_PARTIAL_SPECIALIZATION_IMPLICIT_DEFAULT_ARGS);
    PRINT_MACRO(BOOST_NO_POINTER_TO_MEMBER_CONST);
+   PRINT_MACRO(BOOST_NO_POINTER_TO_MEMBER_TEMPLATE_PARAMETERS);
    PRINT_MACRO(BOOST_NO_PRIVATE_IN_AGGREGATE);
-   PRINT_MACRO(BOOST_NO_SLIST);
+   PRINT_MACRO(BOOST_NO_RESTRICT_REFERENCES);
+   PRINT_MACRO(BOOST_NO_RTTI);
+   PRINT_MACRO(BOOST_NO_SFINAE);
+   PRINT_MACRO(BOOST_NO_SFINAE_EXPR);
+   PRINT_MACRO(BOOST_NO_STDC_NAMESPACE);
    PRINT_MACRO(BOOST_NO_STD_ALLOCATOR);
    PRINT_MACRO(BOOST_NO_STD_DISTANCE);
    PRINT_MACRO(BOOST_NO_STD_ITERATOR);
@@ -894,18 +1208,102 @@ void print_boost_macros()
    PRINT_MACRO(BOOST_NO_STD_MESSAGES);
    PRINT_MACRO(BOOST_NO_STD_MIN_MAX);
    PRINT_MACRO(BOOST_NO_STD_OUTPUT_ITERATOR_ASSIGN);
+   PRINT_MACRO(BOOST_NO_STD_TYPEINFO);
    PRINT_MACRO(BOOST_NO_STD_USE_FACET);
    PRINT_MACRO(BOOST_NO_STD_WSTREAMBUF);
    PRINT_MACRO(BOOST_NO_STD_WSTRING);
-   PRINT_MACRO(BOOST_NO_STDC_NAMESPACE);
    PRINT_MACRO(BOOST_NO_STRINGSTREAM);
    PRINT_MACRO(BOOST_NO_SWPRINTF);
+   PRINT_MACRO(BOOST_NO_TEMPLATED_IOSTREAMS);
+   PRINT_MACRO(BOOST_NO_TEMPLATED_ITERATOR_CONSTRUCTORS);
    PRINT_MACRO(BOOST_NO_TEMPLATE_PARTIAL_SPECIALIZATION);
    PRINT_MACRO(BOOST_NO_TEMPLATE_TEMPLATES);
-   PRINT_MACRO(BOOST_NO_TEMPLATED_ITERATOR_CONSTRUCTORS);
+   PRINT_MACRO(BOOST_NO_TWO_PHASE_NAME_LOOKUP);
+   PRINT_MACRO(BOOST_NO_TYPEID);
+   PRINT_MACRO(BOOST_NO_TYPENAME_WITH_CTOR);
+   PRINT_MACRO(BOOST_NO_UNREACHABLE_RETURN_DETECTION);
+   PRINT_MACRO(BOOST_NO_USING_DECLARATION_OVERLOADS_FROM_TYPENAME_BASE);
    PRINT_MACRO(BOOST_NO_USING_TEMPLATE);
    PRINT_MACRO(BOOST_NO_VOID_RETURNS);
+
+
+
+   // END GENERATED BLOCK
+
+   PRINT_MACRO(BOOST_INTEL);
+   PRINT_MACRO(BOOST_MSVC);
+   PRINT_MACRO(BOOST_GCC);
+   PRINT_MACRO(BOOST_LIBSTDCXX_VERSION);
    PRINT_MACRO(BOOST_STD_EXTENSION_NAMESPACE);
+   PRINT_MACRO(BOOST_UNREACHABLE_RETURN(0));
+   PRINT_MACRO(BOOST_CONSTEXPR);
+   PRINT_MACRO(BOOST_CONSTEXPR_OR_CONST);
+   PRINT_MACRO(BOOST_STATIC_CONSTEXPR);
+   PRINT_MACRO(BOOST_NOEXCEPT);
+   PRINT_MACRO(BOOST_FORCEINLINE);
+   PRINT_MACRO(BOOST_NOINLINE);
+   PRINT_MACRO(BOOST_FALLTHROUGH);
+   PRINT_MACRO(BOOST_MAY_ALIAS);
+   PRINT_MACRO(BOOST_NO_MAY_ALIAS);
+}
+
+void print_sd6_macros()
+{
+    // http://www.open-std.org/jtc1/sc22/wg21/docs/papers/2017/p0096r5.html
+
+    // C++17:
+    PRINT_MACRO(__cpp_hex_float);
+    PRINT_MACRO(__cpp_inline_variables);
+    PRINT_MACRO(__cpp_aligned_new);
+    PRINT_MACRO(__cpp_guaranteed_copy_elision);
+    PRINT_MACRO(__cpp_noexcept_function_type);
+    PRINT_MACRO(__cpp_fold_expressions);
+    PRINT_MACRO(__cpp_capture_star_this);
+    PRINT_MACRO(__cpp_constexpr);
+    PRINT_MACRO(__cpp_if_constexpr);
+    PRINT_MACRO(__cpp_range_based_for);
+    PRINT_MACRO(__cpp_static_assert);
+    PRINT_MACRO(__cpp_deduction_guides);
+    PRINT_MACRO(__cpp_nontype_template_parameter_auto);
+    PRINT_MACRO(__cpp_namespace_attributes);
+    PRINT_MACRO(__cpp_enumerator_attributes);
+    PRINT_MACRO(__cpp_inheriting_constructors);
+    PRINT_MACRO(__cpp_variadic_using);
+    PRINT_MACRO(__cpp_structured_bindings);
+    PRINT_MACRO(__cpp_aggregate_bases);
+    PRINT_MACRO(__cpp_nontype_template_args);
+    PRINT_MACRO(__cpp_template_template_args);
+
+    // C++14:
+    PRINT_MACRO(__cpp_binary_literals);
+    PRINT_MACRO(__cpp_init_captures);
+    PRINT_MACRO(__cpp_generic_lambdas);
+    PRINT_MACRO(__cpp_sized_deallocation);
+    PRINT_MACRO(__cpp_decltype_auto);
+    PRINT_MACRO(__cpp_return_type_deduction);
+    PRINT_MACRO(__cpp_aggregate_nsdmi);
+    PRINT_MACRO(__cpp_variable_templates);
+
+    // C++11:
+    PRINT_MACRO(__cpp_unicode_characters);
+    PRINT_MACRO(__cpp_raw_strings);
+    PRINT_MACRO(__cpp_unicode_literals);
+    PRINT_MACRO(__cpp_user_defined_literals);
+    PRINT_MACRO(__cpp_threadsafe_static_init);
+    PRINT_MACRO(__cpp_lambdas);
+    PRINT_MACRO(__cpp_decltype);
+    PRINT_MACRO(__cpp_attributes);
+    PRINT_MACRO(__cpp_rvalue_references);
+    PRINT_MACRO(__cpp_variadic_templates);
+    PRINT_MACRO(__cpp_initializer_lists);
+    PRINT_MACRO(__cpp_delegating_constructors);
+    PRINT_MACRO(__cpp_nsdmi);
+    PRINT_MACRO(__cpp_ref_qualifiers);
+    PRINT_MACRO(__cpp_alias_templates);
+
+    // C++98:
+    PRINT_MACRO(__cpp_rtti);
+    PRINT_MACRO(__cpp_exceptions);
 }
 
 void print_separator()
@@ -925,12 +1323,8 @@ int main()
   print_platform_macros();
   print_separator();
   print_boost_macros();
+  print_separator();
+  print_sd6_macros();
 
   return 0;
 }
-
-
-
-
-
-
